==> realestate-supervise-common-1.1.0-20220818.055648-18-sources.jar: cn/gtmap/realestate/supervise/entity/BaRzjl.java <==
package cn.gtmap.realestate.supervise.entity;

import javax.persistence.Entity;
import javax.persistence.Id;
import javax.persistence.Table;
import java.io.Serializable;
import java.util.Date;

/**
 * @author <a href="mailto:liuyaozong@gtmap.cn">liuyaozong</a>
 * @version 1.0, 2022/4/19
 * @description 日志记录表 entity
 */
@Entity
@Table(name = "ba_rzjl")
public class BaRzjl implements Serializable {

    private static final long serialVersionUID = -2425020564775078301L;

    // 主键
    @Id
    private String id;

    // 接入行政区代码
    private String jrxzqdm;

    // 不动产单元号
    private String bdcdyh;

    // 接入行政区名称
    private String jrxzqmc;

    // 业务编码
    private String ywbm;

    // 报文行政区代码
    private String bwxzqdm;

    // 操作时间
    private Date czsj;

    // 文件名称
    private String filename;

    // 数据入库操作
    private String sjrkcz;

    // 入库结果
    private String rkjg;

    // 报文路径
    private String bwlj;

    // 响应报文路径
    private String xybwlj;

    // 报文行政区名称
    private String bwxzqmc;

    // 响应编码
    private String xybm;

    // 业务号
    private String ywh;

    // 业务报文ID
    private String ywbwid;

    // 数据状态：0:接收，1:生成响应报文，2:发送响应报文
    private String sjzt;

    // 是否市本级
    private String sfsbj;

    // 报文检查结果
    private String bwjcjg;

    public String getId() {
        return id;
    }

    public void setId(String id) {
        this.id = id;
    }

    public String getJrxzqdm() {
        return jrxzqdm;
    }

    public void setJrxzqdm(String jrxzqdm) {
        this.jrxzqdm = jrxzqdm;
    }

    public String getBdcdyh() {
        return bdcdyh;
    }

    public void setBdcdyh(String bdcdyh) {
        this.bdcdyh = bdcdyh;
    }

    public String getJrxzqmc() {
        return jrxzqmc;
    }

    public void setJrxzqmc(String jrxzqmc) {
        this.jrxzqmc = jrxzqmc;
    }

    public String getYwbm() {
        return ywbm;
    }

    public void setYwbm(String ywbm) {
        this.ywbm = ywbm;
    }

    public String getBwxzqdm() {
        return bwxzqdm;
    }

    public void setBwxzqdm(String bwxzqdm) {
        this.bwxzqdm = bwxzqdm;
    }

    public Date getCzsj() {
        return czsj;
    }

    public void setCzsj(Date czsj) {
        this.czsj = czsj;
    }

    public String getFilename() {
        return filename;
    }

    public void setFilename(String filename) {
        this.filename = filename;
    }

    public String getSjrkcz() {
        return sjrkcz;
    }

    public void setSjrkcz(String sjrkcz) {
        this.sjrkcz = sjrkcz;
    }

    public String getRkjg() {
        return rkjg;
    }

    public void setRkjg(String rkjg) {
        this.rkjg = rkjg;
    }

    public String getBwlj() {
        return bwlj;
    }

    public void setBwlj(String bwlj) {
        this.bwlj = bwlj;
    }

    public String getXybwlj() {
        return xybwlj;
    }

    public void setXybwlj(String xybwlj) {
        this.xybwlj = xybwlj;
    }

    public String getBwxzqmc() {
        return bwxzqmc;
    }

    public void setBwxzqmc(String bwxzqmc) {
        this.bwxzqmc = bwxzqmc;
    }

    public String getXybm() {
        return xybm;
    }

    public void setXybm(String xybm) {
        this.xybm = xybm;
    }

    public String getYwh() {
        return ywh;
    }

    public void setYwh(String ywh) {
        this.ywh = ywh;
    }

    public String getYwbwid() {
        return ywbwid;
    }

    public void setYwbwid(String ywbwid) {
        this.ywbwid = ywbwid;
    }

    public String getSjzt() {
        return sjzt;
    }

    public void setSjzt(String sjzt) {
        this.sjzt = sjzt;
    }

    public String getSfsbj() {
        return sfsbj;
    }

    public void setSfsbj(String sfsbj) {
        this.sfsbj = sfsbj;
    }

    public String getBwjcjg() {
        return bwjcjg;
    }

    public void setBwjcjg(String bwjcjg) {
        this.bwjcjg = bwjcjg;
    }
}

==> realestate-supervise-common-1.1.0-20251204.005843-70-sources.jar: cn/gtmap/realestate/supervise/entity/BaRzjl.java <==
package cn.gtmap.realestate.supervise.entity;

import javax.persistence.Entity;
import javax.persistence.Id;
import javax.persistence.Table;
import java.io.Serializable;
import java.util.Date;

/**
 * @author <a href="mailto:liuyaozong@gtmap.cn">liuyaozong</a>
 * @version 1.0, 2022/4/19
 * @description 日志记录表 entity
 */
@Entity
@Table(name = "ba_rzjl")
public class BaRzjl implements Serializable {

    private static final long serialVersionUID = -2425020564775078301L;

    // 主键
    @Id
    private String id;

    // 接入行政区代码
    private String jrxzqdm;

    // 不动产单元号
    private String bdcdyh;

    // 接入行政区名称
    private String jrxzqmc;

    // 业务编码
    private String ywbm;

    // 报文行政区代码
    private String bwxzqdm;

    // 操作时间
    private Date czsj;

    // 文件名称
    private String filename;

    // 数据入库操作
    private String sjrkcz;

    // 入库结果
    private String rkjg;

    // 报文路径
    private String bwlj;

    // 响应报文路径
    private String xybwlj;

    // 报文行政区名称
    private String bwxzqmc;

    // 响应编码
    private String xybm;

    // 业务号
    private String ywh;

    // 业务报文ID
    private String ywbwid;

    // 数据状态：0:接收，1:生成响应报文，2:发送响应报文
    private String sjzt;

    // 是否市本级
    private String sfsbj;

    // 报文检查结果
    private String bwjcjg;

    private String djlx;

    private String qllx;

    private Date rksj;

    public String getDjlx() {
        return djlx;
    }

    public void setDjlx(String djlx) {
        this.djlx = djlx;
    }

    public String getQllx() {
        return qllx;
    }

    public void setQllx(String qllx) {
        this.qllx = qllx;
    }

    public String getId() {
        return id;
    }

    public void setId(String id) {
        this.id = id;
    }

    public String getJrxzqdm() {
        return jrxzqdm;
    }

    public void setJrxzqdm(String jrxzqdm) {
        this.jrxzqdm = jrxzqdm;
    }

    public String getBdcdyh() {
        return bdcdyh;
    }

    public void setBdcdyh(String bdcdyh) {
        this.bdcdyh = bdcdyh;
    }

    public String getJrxzqmc() {
        return jrxzqmc;
    }

    public void setJrxzqmc(String jrxzqmc) {
        this.jrxzqmc = jrxzqmc;
    }

    public String getYwbm() {
        return ywbm;
    }

    public void setYwbm(String ywbm) {
        this.ywbm = ywbm;
    }

    public String getBwxzqdm() {
        return bwxzqdm;
    }

    public void setBwxzqdm(String bwxzqdm) {
        this.bwxzqdm = bwxzqdm;
    }

    public Date getCzsj() {
        return czsj;
    }

    public void setCzsj(Date czsj) {
        this.czsj = czsj;
    }

    public String getFilename() {
        return filename;
    }

    public void setFilename(String filename) {
        this.filename = filename;
    }

    public String getSjrkcz() {
        return sjrkcz;
    }

    public void setSjrkcz(String sjrkcz) {
        this.sjrkcz = sjrkcz;
    }

    public String getRkjg() {
        return rkjg;
    }

    public void setRkjg(String rkjg) {
        this.rkjg = rkjg;
    }

    public String getBwlj() {
        return bwlj;
    }

    public void setBwlj(String bwlj) {
        this.bwlj = bwlj;
    }

    public String getXybwlj() {
        return xybwlj;
    }

    public void setXybwlj(String xybwlj) {
        this.xybwlj = xybwlj;
    }

    public String getBwxzqmc() {
        return bwxzqmc;
    }

    public void setBwxzqmc(String bwxzqmc) {
        this.bwxzqmc = bwxzqmc;
    }

    public String getXybm() {
        return xybm;
    }

    public void setXybm(String xybm) {
        this.xybm = xybm;
    }

    public String getYwh() {
        return ywh;
    }

    public void setYwh(String ywh) {
        this.ywh = ywh;
    }

    public String getYwbwid() {
        return ywbwid;
    }

    public void setYwbwid(String ywbwid) {
        this.ywbwid = ywbwid;
    }

    public String getSjzt() {
        return sjzt;
    }

    public void setSjzt(String sjzt) {
        this.sjzt = sjzt;
    }

    public String getSfsbj() {
        return sfsbj;
    }

    public void setSfsbj(String sfsbj) {
        this.sfsbj = sfsbj;
    }

    public String getBwjcjg() {
        return bwjcjg;
    }

    public void setBwjcjg(String bwjcjg) {
        this.bwjcjg = bwjcjg;
    }

    public Date getRksj() {
        return rksj;
    }

    public void setRksj(Date rksj) {
        this.rksj = rksj;
    }
}
